==> jc-1.4.0.tar.gz: javax/swing/text/Position__24Bias.c <==
// public class javax.swing.text.Position$Bias

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 209ce85d8c9a3fdc javax_swing_text_Position
// @dep_class fa42467a9d08efa6 javax_swing_text_Position__24Bias

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_text_Position
// @dep_header javax_swing_text_Position__24Bias

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/text/Position.h"
#include "javax/swing/text/Position__24Bias.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final javax.swing.text.Position$Bias Backward
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$Backward = {
	.name=		"Backward",
	.signature=	"Ljavax/swing/text/Position$Bias;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_javax_swing_text_Position__24Bias$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$fields_struct, Backward),
};

// public static final javax.swing.text.Position$Bias Forward
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$Forward = {
	.name=		"Forward",
	.signature=	"Ljavax/swing/text/Position$Bias;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_javax_swing_text_Position__24Bias$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$fields_struct, Forward),
};

// private java.lang.String name
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$object, refs[-1].javax_swing_text_Position__24Bias.name),
};

// Fields
static _jc_field *const _jc_javax_swing_text_Position__24Bias$fields[] = {
	&_jc_javax_swing_text_Position__24Bias$field_info$Backward,
	&_jc_javax_swing_text_Position__24Bias$field_info$Forward,
	&_jc_javax_swing_text_Position__24Bias$field_info$name
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static final void <clinit>()
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, _clinit$a816641e0ba8bfef);

void
_jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r3;

	_JC_LINE_NUMBER(45);				// 0
	r0 = _JC_NEW(env, javax_swing_text_Position__24Bias);
	r1 = _JC_STRING(env, "backward");
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r1;
	_JC_STATIC_FIELD(env, javax_swing_text_Position__24Bias, Backward, 1) = r0;
	_JC_LINE_NUMBER(46);				// 1
	r0 = _JC_NEW(env, javax_swing_text_Position__24Bias);
	r3 = _JC_STRING(env, "forward");
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r3;
	_JC_STATIC_FIELD(env, javax_swing_text_Position__24Bias, Forward, 1) = r0;
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>(java.lang.String)
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_text_Position__24Bias$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.param_types=		&_jc_javax_swing_text_Position__24Bias$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, _init$c31b894660454d13);

void
_jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13(_jc_env *const env, _jc_javax_swing_text_Position__24Bias$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(52);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r1;
	_JC_LINE_NUMBER(53);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_text_Position__24Bias$vtable, javax_swing_text_Position__24Bias.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_swing_text_Position__24Bias$object *this)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(57);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_Position__24Bias$methods[] = {
	&_jc_javax_swing_text_Position__24Bias$method_info$_clinit$a816641e0ba8bfef,
	&_jc_javax_swing_text_Position__24Bias$method_info$_init$c31b894660454d13,
	&_jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_text_Position__24Bias$fields_struct _jc_javax_swing_text_Position__24Bias$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_38[] = {
	&_jc_javax_swing_text_Position__24Bias$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[38]=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_38,
	[113]=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_Position__24Bias$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/text/Position",	_JC_JLONG(0x209ce85d8c9a3fdc) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_Position__24Bias$vtype _jc_javax_swing_text_Position__24Bias$type = {
    .type= {
	.name=			"javax/swing/text/Position$Bias",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xfa42467a9d08efa6),
		.source_file=		"Position.java",
		.instance_size=		sizeof(_jc_javax_swing_text_Position__24Bias$refs) + sizeof(_jc_javax_swing_text_Position__24Bias$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_text_Position__24Bias$fields) / sizeof(*_jc_javax_swing_text_Position__24Bias$fields),
		.fields=		_jc_javax_swing_text_Position__24Bias$fields,
		.num_methods=		sizeof(_jc_javax_swing_text_Position__24Bias$methods) / sizeof(*_jc_javax_swing_text_Position__24Bias$methods),
		.methods=		_jc_javax_swing_text_Position__24Bias$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_text_Position__24Bias$class_fields,
		.outer_class=		&_jc_javax_swing_text_Position$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_Position__24Bias$class_depends) / sizeof(*_jc_javax_swing_text_Position__24Bias$class_depends),
		.class_depends=		_jc_javax_swing_text_Position__24Bias$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_Position__24Bias= {
	    .toString$7ea43b33b80a3070=
		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/text/Position__24Bias.c <==
// public class javax.swing.text.Position$Bias

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 209ce85d8c9a3fdc javax_swing_text_Position
// @dep_class fa42467a9d08efa6 javax_swing_text_Position__24Bias

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_text_Position
// @dep_header javax_swing_text_Position__24Bias

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/text/Position.h"
#include "javax/swing/text/Position__24Bias.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final javax.swing.text.Position$Bias Backward
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$Backward = {
	.name=		"Backward",
	.signature=	"Ljavax/swing/text/Position$Bias;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_javax_swing_text_Position__24Bias$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$fields_struct, Backward),
};

// public static final javax.swing.text.Position$Bias Forward
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$Forward = {
	.name=		"Forward",
	.signature=	"Ljavax/swing/text/Position$Bias;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_javax_swing_text_Position__24Bias$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$fields_struct, Forward),
};

// private java.lang.String name
static _jc_field _jc_javax_swing_text_Position__24Bias$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_text_Position__24Bias$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_Position__24Bias$object, refs[-1].javax_swing_text_Position__24Bias.name),
};

// Fields
static _jc_field *const _jc_javax_swing_text_Position__24Bias$fields[] = {
	&_jc_javax_swing_text_Position__24Bias$field_info$Backward,
	&_jc_javax_swing_text_Position__24Bias$field_info$Forward,
	&_jc_javax_swing_text_Position__24Bias$field_info$name
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static final void <clinit>()
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, _clinit$a816641e0ba8bfef);

void _JC_JCNI_ATTR
_jc_javax_swing_text_Position__24Bias$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r3;

	_JC_LINE_NUMBER(45);				// 0
	r0 = _JC_NEW(env, javax_swing_text_Position__24Bias);
	r1 = _JC_STRING(env, "backward");
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r1;
	_JC_STATIC_FIELD(env, javax_swing_text_Position__24Bias, Backward, 1) = r0;
	_JC_LINE_NUMBER(46);				// 1
	r0 = _JC_NEW(env, javax_swing_text_Position__24Bias);
	r3 = _JC_STRING(env, "forward");
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r3;
	_JC_STATIC_FIELD(env, javax_swing_text_Position__24Bias, Forward, 1) = r0;
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>(java.lang.String)
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_text_Position__24Bias$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.param_types=		&_jc_javax_swing_text_Position__24Bias$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_javax_swing_text_Position__24Bias$method$_init$c31b894660454d13(_jc_env *const env, _jc_javax_swing_text_Position__24Bias$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(52);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name) = r1;
	_JC_LINE_NUMBER(53);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_javax_swing_text_Position__24Bias$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_swing_text_Position__24Bias$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_text_Position__24Bias$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_text_Position__24Bias$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_text_Position__24Bias$vtable, javax_swing_text_Position__24Bias.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_Position__24Bias$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_Position__24Bias, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_swing_text_Position__24Bias$object *this)
{
	struct _jc_javax_swing_text_Position__24Bias$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(57);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_text_Position__24Bias, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_Position__24Bias$methods[] = {
	&_jc_javax_swing_text_Position__24Bias$method_info$_clinit$a816641e0ba8bfef,
	&_jc_javax_swing_text_Position__24Bias$method_info$_init$c31b894660454d13,
	&_jc_javax_swing_text_Position__24Bias$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_text_Position__24Bias$fields_struct _jc_javax_swing_text_Position__24Bias$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_38[] = {
	&_jc_javax_swing_text_Position__24Bias$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_Position__24Bias$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[38]=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_38,
	[101]=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_Position__24Bias$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/text/Position",	_JC_JLONG(0x209ce85d8c9a3fdc) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_Position__24Bias$vtype _jc_javax_swing_text_Position__24Bias$type = {
    .type= {
	.name=			"javax/swing/text/Position$Bias",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xfa42467a9d08efa6),
		.source_file=		"Position.java",
		.instance_size=		sizeof(_jc_javax_swing_text_Position__24Bias$refs) + sizeof(_jc_javax_swing_text_Position__24Bias$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_text_Position__24Bias$fields) / sizeof(*_jc_javax_swing_text_Position__24Bias$fields),
		.fields=		_jc_javax_swing_text_Position__24Bias$fields,
		.num_methods=		sizeof(_jc_javax_swing_text_Position__24Bias$methods) / sizeof(*_jc_javax_swing_text_Position__24Bias$methods),
		.methods=		_jc_javax_swing_text_Position__24Bias$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_Position__24Bias$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_text_Position__24Bias$class_fields,
		.outer_class=		&_jc_javax_swing_text_Position$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_Position__24Bias$class_depends) / sizeof(*_jc_javax_swing_text_Position__24Bias$class_depends),
		.class_depends=		_jc_javax_swing_text_Position__24Bias$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_Position__24Bias= {
	    .toString$7ea43b33b80a3070=
		&_jc_javax_swing_text_Position__24Bias$method$toString$7ea43b33b80a3070,
	},
    }
};
